clearAmbientCache function
Removes all tiles from the shared ambient cache that are not associated with any offline region. Call this after deleteOfflineRegion to fully evict tiles that would otherwise be reused by a future download of the same area.
Implementation
Future<void> clearAmbientCache() =>
_globalChannel.invokeMethod('clearAmbientCache');